#========================================================================================
# package      DE_EPAGES::Catalog::DAL::CategoryProductMap
# state        private
# description  database interface for tables:
#               <ul>
#                   <li>categoryproductmap
#               </ul>
#========================================================================================
package DE_EPAGES::Catalog::DAL::CategoryProductMap;
use base qw (Exporter);

use strict;
our @EXPORT = qw (
    DAL_GetProductIDsByCategoryID
    DAL_RenumberCategoryProductsByCategoryID
);

use DE_EPAGES::Core::API::Log qw ( GetLog );
use DE_EPAGES::Database::API::Connection qw (  GetCurrentDBHandle );

my $DO_CACHE = 1;

sub _CallDriver {
    my ($FunctionName, @Parameter) = @_;
    my $dbi = GetCurrentDBHandle();
    my $Package = 'DE_EPAGES::Catalog::DAL::'.$dbi->driverName.'::CategoryProductMap';
    DE_EPAGES::Core::API::PerlTools::UsePackage($Package);
    GetLog->debug("call $Package->$FunctionName()");
    return $Package->$FunctionName($dbi, @Parameter);
}


#========================================================================================
# function     DAL_GetProductIDsByCategoryID
# state        public
#----------------------------------------------------------------------------------------
# syntax       $aCategoryProductMaps = DAL_GetProductIDsByCategoryID($CategoryID);
#----------------------------------------------------------------------------------------
# description  get affected categoryproductmapids for categoryid
#----------------------------------------------------------------------------------------
# input        $CategoryID | category id | integer
# return       $aCategoryProductMapIDs | affected category product map ids | ref.array.ref.array
#========================================================================================
sub DAL_GetProductIDsByCategoryID ($) {
    my ($CategoryID) = @_;

    return _CallDriver('GetProductIDsByCategoryID', $CategoryID);
}

#========================================================================================
# function     DAL_RenumberCategoryProductsByCategoryID
# state        public
#----------------------------------------------------------------------------------------
# syntax       DAL_RenumberCategoryProductsByCategoryID($CategoryID,$StepSize);
#----------------------------------------------------------------------------------------
# description  renumbers all categoryproductmaps position for a specific category id
#               renumber is done on database for high performance
#----------------------------------------------------------------------------------------
# input        $CategoryID | category id | integer
# input        $StepSize | step size e.g. 10 | integer
#========================================================================================
sub DAL_RenumberCategoryProductsByCategoryID ($$) {
    my ($CategoryID,$StepSize) = @_;

    return _CallDriver('RenumberCategoryProductsByCategoryID', $CategoryID, $StepSize);
}

1;
