#========================================================================================
# §package      DE_EPAGES::Catalog::DAL::mysql::CategoryProductMap
# §state        private
# §description  Generic mysql database interface for tables:
#               <ul>
#                   <li>categoryproductmap
#               </ul>
#========================================================================================
package DE_EPAGES::Catalog::DAL::mysql::CategoryProductMap;

use strict;

#========================================================================================
# §function     GetProductIDsByCategoryID
# §state        public
#----------------------------------------------------------------------------------------
# §syntax       DE_EPAGES::Catalog::DAL::mysql::CategoryProductMap->GetProductIDsByCategoryID($dbi, $CategoryID);
#----------------------------------------------------------------------------------------
# §description  get affected categoryproductmapids for categoryid
#----------------------------------------------------------------------------------------
# §input        $CategoryID | category id | integer
#========================================================================================
sub GetProductIDsByCategoryID{
    my $self = shift;
    my ($dbi, $CategoryID) = @_;

    my $sql = 'SELECT categoryproductmapid FROM categoryproductmap cpm WHERE cpm.categoryid=?';
    my $dbResult = $dbi->execute($sql, [$CategoryID], ['Integer']);
    return $dbResult;
}

#========================================================================================
# §function     RenumberCategoryProductsByCategoryID
# §state        public
#----------------------------------------------------------------------------------------
# §syntax       DE_EPAGES::Catalog::DAL::mysql::CategoryProductMap->RenumberCategoryProductsByCategoryID($dbi, $CategoryID, $StepSize);
#----------------------------------------------------------------------------------------
# §description  renumbers all categoryproductmaps position for a specific category id
#               renumber is done on database for high performance
#----------------------------------------------------------------------------------------
# §input        $CategoryID | category id | integer
# §input        $StepSize | step size e.g. 10 | integer
#========================================================================================
sub RenumberCategoryProductsByCategoryID{
    my $self = shift;
    my ($dbi, $CategoryID, $StepSize) = @_;

    my $sql_set_variable = 'SET @row_number=0';
    my $sql_renumber = 'UPDATE categoryproductmap ' .
        'SET position=(@row_number:=@row_number+?) ' .
        'WHERE categoryid=? ' .
        'ORDER BY position ASC';

    $dbi->do($sql_set_variable);
    $dbi->do($sql_renumber, [$StepSize, $CategoryID]);

    return 1;
}

1;
