#!/bin/bash


BN=${0##*/}
DN=$(cd $(dirname $0) && pwd)

#-----------------------------------------------------------------------
# setup-flex-env.sh
#-----------------------------------------------------------------------

#=======================================================================
# set variables
#=======================================================================

. /etc/default/epages6

# command for rotate log files
COMMAND="$EPAGES_CARTRIDGES/DE_EPAGES/Core/bin/logfilemgmt.sh"

# search directory/ies for log files (separated by ' ')
SEARCHDIR=$(mktemp -d)
cd $SEARCHDIR

# -s SIZE[ckm]: required size (in bytes, KB, MB) to compress
SIZE="-s 10m"

# -d DAYS: remove compressed files older than DAYS (unset -> don't remove)
DAYS="-d 8"

# -a DIR: move compressed files into ARCHIVE directory
ARCHIVE="-a $SEARCHDIR/Archive"

#=======================================================================
# write mock data
#=======================================================================

write_mock_data() {
  for i in {0..5} ; do
    for j in {0..2} ; do
      fallocate -l $((10 ** i))K ${i}${j}_log
    done
  done
}

########################################################################
# execution
########################################################################

write_mock_data

#=======================================================================
# rotate by size
#=======================================================================

for i in {5..0} ; do
  echo "$COMMAND -s $((10 ** i))k $ARCHIVE $SEARCHDIR"
  $COMMAND -s $((10 ** i))k $ARCHIVE $SEARCHDIR
  expected=$(((5 - i) * 3))
  zipped=$(find ${ARCHIVE#* } -type f -printf "%f\n" | wc -l)
  echo "files in ${ARCHIVE#* }: expected=$expected; found=$zipped"
  if [[ $zipped != $expected ]] ; then
    echo "ERROR: expected differs from found"
    exit 1
  fi
done

#=======================================================================
# delete archived files older than 5 days
#=======================================================================

for i in ${ARCHIVE#* }/5*gz ; do
  touch -d "$(date --date='10 days ago')" $i
done

before=$(find ${ARCHIVE#* } -type f -printf "%f\n" | wc -l)
echo "files in ${ARCHIVE#* }: before=$before"
echo "$COMMAND -s 100k -d 5 $ARCHIVE $SEARCHDIR"
$COMMAND -s 100k -d 5 $ARCHIVE $SEARCHDIR
after=$(find ${ARCHIVE#* } -type f -printf "%f\n" | wc -l)
echo "files in ${ARCHIVE#* }: after=$after"

if [[ $before != $((after + 3)) ]] ; then
  echo "ERROR: expected differs from found"
  exit 1
fi

#=======================================================================
# remove mock data
#=======================================================================

rm -rf $SEARCHDIR

exit 0
