#========================================================================================
# package      DE_EPAGES::Coupon::Hooks::LineItemCoupon
# state        public
# description  deletes value from LineItemProduct
#========================================================================================
package DE_EPAGES::Coupon::Hooks::LineItemCoupon;
use DE_EPAGES::Core::API::PerlTools qw (IsA);
use strict;
#========================================================================================
# function     OnDeleteLineItemCoupon
#----------------------------------------------------------------------------------------
# syntax       OnDeleteLineItemCoupon( $hParams );
#----------------------------------------------------------------------------------------
# description  OnDeleteLineItemCoupon is triggered when a coupon will be deleted from
#               the basket.
#----------------------------------------------------------------------------------------
# input        $hParams | parameters
#               <ul>
#                   <li>Object | LineItemCoupon | DE_EPAGES::Coupon::API::Object::LineItemCoupon
#                   <li>LineItemID  | object id LineItemCoupon | number
#               </ul> | ref.hash.*
#========================================================================================
sub OnDeleteLineItemCoupon {
    my ($hParams) = @_;

    my $LineItemCoupon = $hParams->{'Object'};
    return unless $LineItemCoupon;
    return unless IsA( $LineItemCoupon, 'DE_EPAGES::Coupon::API::Object::LineItemCoupon' );

    my $LineItemContainer = $LineItemCoupon->container();
    return unless $LineItemContainer;
    return unless IsA( $LineItemContainer, 'DE_EPAGES::Order::API::Object::LineItemContainer' );

    my $aLineItems = $LineItemContainer->children();

    foreach my $LineItem (@{$aLineItems}){
        if(IsA( $LineItem, 'DE_EPAGES::Product::API::Object::LineItemProduct' )){
            $LineItem->set({'CouponDiscount' => undef});
        }
    }
    return;
}

1;

