#========================================================================================
# package      DE_EPAGES::Coupon::t::unit::Hook_LineItemCoupon
# base         DE_EPAGES::Test::API::UnitTest::Test
#----------------------------------------------------------------------------------------
# description  unit test for DE_EPAGES::Coupon::Hooks::LineItemCoupon
#========================================================================================
package DE_EPAGES::Coupon::t::unit::Hook_LineItemCoupon;
use base DE_EPAGES::Test::API::UnitTest::Test;

use DE_EPAGES::Coupon::Hooks::LineItemCoupon;
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use Test::More;

use strict;

sub test {
    my $self = shift;

    $self->test_UndefLineItems();
    $self->test_NoLineItems();
    $self->test_OneProduct();
    $self->test_TwoProductsAndAShipping();

    done_testing();
}
#----------------------------------------------------------------------------------------
sub test_UndefLineItems {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $LineItemCoupon = $self->_createLineItemCoupon();
    my $Result = DE_EPAGES::Coupon::Hooks::LineItemCoupon::OnDeleteLineItemCoupon({
        'Object' => $LineItemCoupon,
    } );

    is($Result, undef, "$SubTestName - Lives OK");
}
#----------------------------------------------------------------------------------------
sub test_NoLineItems {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $LineItemCoupon = $self->_createLineItemCoupon([]);
    my $Result = DE_EPAGES::Coupon::Hooks::LineItemCoupon::OnDeleteLineItemCoupon({
        'Object' => $LineItemCoupon,
    } );

    is($Result, undef, "$SubTestName - Lives OK");
}
#----------------------------------------------------------------------------------------
sub test_OneProduct {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $Product = $self->_createLineItemProduct('OneProduct');
    my $LineItemCoupon = $self->_createLineItemCoupon([$Product]);
    my $Result = DE_EPAGES::Coupon::Hooks::LineItemCoupon::OnDeleteLineItemCoupon({
        'Object' => $LineItemCoupon,
    } );

    is($Result, undef, "$SubTestName - Lives OK");
    is($Product->alias(), 'OneProduct', "$SubTestName - proves if this is the correct product");
    is($Product->get('CouponDiscount'), undef, "$SubTestName - proves if CouponDiscount is set to undef");
}
#----------------------------------------------------------------------------------------
sub test_TwoProductsAndAShipping {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $ProductOne = $self->_createLineItemProduct('ProductOne');
    my $ProductTwo = $self->_createLineItemProduct('ProductTwo');
    my $Shipping = $self->_createLineItemShipping();
    my $LineItemCoupon = $self->_createLineItemCoupon([$ProductOne, $ProductTwo, $Shipping]);
    my $Result = DE_EPAGES::Coupon::Hooks::LineItemCoupon::OnDeleteLineItemCoupon({
        'Object' => $LineItemCoupon,
    } );

    is($Result, undef, "$SubTestName - Lives OK");
    is($ProductOne->alias(), 'ProductOne', "$SubTestName - proves if this is the correct 'ProductOne'");
    is($ProductTwo->alias(), 'ProductTwo', "$SubTestName - proves if this is the correct 'ProductTwo'");
    is($Shipping->alias(), 'SuperShip', "$SubTestName - proves if shipping is still there");

    is($ProductOne->get('CouponDiscount'), undef, "$SubTestName - proves if CouponDiscount is set to undef 'ProductOne'");
    is($ProductTwo->get('CouponDiscount'), undef, "$SubTestName - proves if CouponDiscount is set to undef 'ProductTwo'");
}
#----------------------------------------------------------------------------------------
# helpers
#----------------------------------------------------------------------------------------
#----------------------------------------------------------------------------------------
sub _createLineItemCoupon {
    my $self = shift;
    my ($aProducts) = @_;
    my $hAttributes = {
        'LineItemContainer' => $self->_createLineItemContainer($aProducts),
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Coupon::API::Object::LineItemCoupon',
        $hAttributes
    );

    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createLineItemContainer {
    my $self = shift;
    my ($aProducts) = @_;

    my $hAttributes = {
        'Children' => $aProducts,
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Order::API::Object::LineItemContainer',
        $hAttributes
    );

    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createLineItemProduct {
    my $self = shift;
    my ($Alias) = @_;

    my $hAttributes = {
        'Alias' => $Alias,
        'CouponDiscount' => 7.3,
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Product::API::Object::LineItemProduct',
        $hAttributes
    );

    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createLineItemShipping {
    my $self = shift;
    my ($Alias) = @_;

    my $hAttributes = {
        'Alias' => 'SuperShip',
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Order::API::Object::LineItemShipping',
        $hAttributes
    );

    return $Mockify->getMockObject();
}
__PACKAGE__->runScript();