#========================================================================================
# package      DE_EPAGES::DHLIntraship::t::unit::ShippingLabelRequest_Address
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for Address module.
#========================================================================================
package DE_EPAGES::DHLIntraship::t::unit::ShippingLabelRequest_AddressReceiver;
use base DE_EPAGES::Test::API::UnitTest::Test;

use DE_EPAGES::DHLIntraship::API::SOAP::ShippingLabelRequest::AddressReceiver;
use DE_EPAGES::Test::Mock::Mockify;
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use Test::More;

use strict;

use constant TEST_ADDRESS_STREET2 => 'Catalunya';
use constant TEST_ADDRESS_STREET2_TOO_LONG => 'street name that exceeds the maximum characters limit';
use constant TEST_ADDRESS_ADDRESS_EXTENSION => 'Barcelona';
use constant TEST_ADDRESS_COMPANY => 'Diagonal';
use constant TEST_ADDRESS_COMPANY_TOO_LONG => 'company name that exceeds the maximum characters limit';

#========================================================================================
sub test {
    my $self = shift;

    $self->address_assemble_positive_test_all_fields();
    $self->address_assemble_positive_test_only_Street2();
    $self->address_assemble_address_fields_too_long_test();

    done_testing();
}

#========================================================================================
# Test methods
#========================================================================================
sub address_assemble_positive_test_all_fields {
    my $self = shift;
    my $SubTestName = ( caller(0) )[3];

    my $MockedCustomerAddress = $self->_createAddress(
        {
            'Street2' => TEST_ADDRESS_STREET2,
            'AddressExtension' => TEST_ADDRESS_ADDRESS_EXTENSION,
            'Company' => TEST_ADDRESS_COMPANY,
        }
    );

    my $SUT = $self->_createSUT();
    my $hAddress = $SUT->assemble($MockedCustomerAddress);

    is_deeply($hAddress->{'nodeData'},
        { 'Address' => {
              'addressAddition' => TEST_ADDRESS_ADDRESS_EXTENSION . ' ' . TEST_ADDRESS_STREET2,
              'name2' => TEST_ADDRESS_COMPANY,
          }
        },
        "$SubTestName - Receiver Address hash assembled"
    );
    is_deeply($hAddress->{'nodeWarnings'}, [], "$SubTestName - warnings array for Address is empty");
}

sub address_assemble_positive_test_only_Street2 {
    my $self = shift;
    my $SubTestName = ( caller(0) )[3];

    my $MockedCustomerAddress = $self->_createAddress(
        {
            'Street2' => TEST_ADDRESS_STREET2,
        }
    );

    my $SUT = $self->_createSUT();
    my $hAddress = $SUT->assemble($MockedCustomerAddress);

    is_deeply($hAddress->{'nodeData'},
        { 'Address' => {
              'addressAddition' => TEST_ADDRESS_STREET2,
          }
        },
        "$SubTestName - Receiver Address hash assembled"
    );
    is_deeply($hAddress->{'nodeWarnings'}, [], "$SubTestName - warnings array for Address is empty");
}

sub address_assemble_address_fields_too_long_test {
    my $self = shift;
    my $SubTestName = ( caller(0) )[3];
    
    my $MockedCustomerAddress = $self->_createAddress(
        {
            'Street2' => TEST_ADDRESS_STREET2_TOO_LONG,
            'Company' => TEST_ADDRESS_COMPANY_TOO_LONG,
        }
    );

    my $SUT = $self->_createSUT();
    my $hAddress = $SUT->assemble($MockedCustomerAddress);

    my $AddressExtensionResult = $hAddress->{'nodeData'}->{'Address'}->{'addressAddition'};
    my $CompanyResult = $hAddress->{'nodeData'}->{'Address'}->{'name2'};

    is(length($AddressExtensionResult), 35, ## no critic (ProhibitMagicNumbers)
        "$SubTestName - addressAddition has been trimmed because it was too long"
    );

    is(length($CompanyResult), 50, ## no critic (ProhibitMagicNumbers)
        "$SubTestName - name2 has been trimmed because it was too long"
    );

    is_deeply($hAddress->{'nodeWarnings'},
        [
            { 'addressAddition' => 'StringTooLong' },
            { 'name2' => 'StringTooLong' }
        ],
        "$SubTestName - warnings array for Address holds addressAddition and company messages about being too long"
    );
}

#========================================================================================
# Mocking methods
#========================================================================================
sub _createAddress {
    my $self = shift;
    my ($hAddress) = @_;

    my $hParameterList = {
        'Street2' => $hAddress->{'Street2'},
        'AddressExtension' => $hAddress->{'AddressExtension'},
        'Company' => $hAddress->{'Company'},
    };

    my $MockAddress = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
            'DE_EPAGES::Address::API::Object::Address',
            $hParameterList
    );

    return $MockAddress->getMockObject();
}

sub _createSUT {
    my $self = shift;

    my $aParameterList = [];

    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new(
        'DE_EPAGES::DHLIntraship::API::SOAP::ShippingLabelRequest::AddressReceiver',
        $aParameterList
    );

    my $hAddressReturn = {
        'nodeData' => {
            'Address' => {}
        },
        'nodeWarnings' => []
    };

    $Mockify->addMockWithReturnValueAndParameterCheck(
            '_assembleAddress', $hAddressReturn, [ { 'object' => 'DE_EPAGES::Address::API::Object::Address' } ]
    );

    return $Mockify->getMockObject();
}

__PACKAGE__->runScript;
