#========================================================================================
# package      DE_EPAGES::GoogleBase::t::unit::GoogleBaseProductsExportDriver
# base         DE_EPAGES::Test::API::UnitTest::Test
#----------------------------------------------------------------------------------------
# description  unit test for GoogleBaseProductsExportDriver
#========================================================================================
package DE_EPAGES::GoogleBase::t::unit::GoogleBaseProductsExportDriver;
use base DE_EPAGES::Test::API::UnitTest::Test;

use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use Test::More;
use Test::Mockify;
use Test::Mockify::Matcher qw ( String  HashRef );
use Test::Mockify::Verify qw ( GetParametersFromMockifyCall WasCalled GetCallCount );
use DE_EPAGES::GoogleBase::API::CSV::GoogleBaseProductsExportDriver;
use strict;

sub test {
    my $self = shift;

    $self->test_google_product_category_Uppercase_export();
    $self->test_google_product_category_Lowercase_export();
    $self->test_google_product_category_export_emptyValue();
    $self->test_google_product_category_export_AttributeDontExists();
    $self->test_google_product_category_removeUnexpectedCharacters();
    done_testing();
}
#----------------------------------------------------------------------------------------
sub test_google_product_category_Uppercase_export {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $SUT = $self->_createSUT();
    my $Product = $self->_createProduct({
        'Google_Product_Category' => 'TestCategory',
        'ProductTypeAttributes' => [
            'Google_Product_Category',
        ]
    });

    my $Result = $SUT->google_product_category( $Product );

    is( $Result, 'TestCategory', "$SubTestName - prove that the google category is exported." );
    is( WasCalled($SUT, '_Warning'), 0, "$SubTestName - prove that no warning was created." );
}
#----------------------------------------------------------------------------------------
sub test_google_product_category_Lowercase_export {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $SUT = $self->_createSUT();
    my $Product = $self->_createProduct({
        'google_product_category' => 'TestUnityCategory',
        'ProductTypeAttributes' => [
            'google_product_category',
        ]
    });

    my $Result = $SUT->google_product_category( $Product );

    is( $Result, 'TestUnityCategory', "$SubTestName - prove that the google category is exported." );
    is( WasCalled($SUT, '_Warning'), 0, "$SubTestName - prove that no warning was created." );
}
#----------------------------------------------------------------------------------------
sub test_google_product_category_export_emptyValue {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $SUT = $self->_createSUT();
    my $Product = $self->_createProduct({
        'Google_Product_Category' => undef,
        'google_product_category' => undef,
        'ProductTypeAttributes' => [
            'Google_Product_Category',
            'google_product_category',
        ]
    });

    my $Result = $SUT->google_product_category( $Product );

    is($Result, undef, "$SubTestName - prove that the google category is exporting undef.");

    is(GetCallCount($SUT, '_Warning'),1,"$SubTestName - prove that one warning was created.");
    my $aParameters = GetParametersFromMockifyCall($SUT, '_Warning');
    is($aParameters->[0],'ProductNoGoogleCategory',"$SubTestName - prove that the warning name is set.");
    is_deeply(
        $aParameters->[1]->{'AttributeAlias'},
        'Google_Product_Category or google_product_category',
        "$SubTestName - prove that the 'AttributeAlias' is set."
    );
    is_deeply($aParameters->[1]->{'ProductID'}, 666, "$SubTestName - prove that the 'ProductID' is set.");
    isa_ok($aParameters->[1]->{'Product'}, 'DE_EPAGES::Product::API::Object::Product');
}

#----------------------------------------------------------------------------------------
sub test_google_product_category_export_AttributeDontExists {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $SUT = $self->_createSUT();
    my $Product = $self->_createProduct({
        'Google_Product_Category' => undef,
        'google_product_category' => undef,
        'ProductTypeAttributes' => [ ]
    });

    my $Result = $SUT->google_product_category( $Product );

    is($Result, undef, "$SubTestName - prove that the google category is exporting undef.");

    is(GetCallCount($SUT, '_Warning'),1,"$SubTestName - prove that one warning was created.");
    my $aParameters = GetParametersFromMockifyCall($SUT, '_Warning');
    is($aParameters->[0],'ProductNoGoogleCategory',"$SubTestName - prove that the warning name is set.");
    is_deeply(
        $aParameters->[1]->{'AttributeAlias'},
        'Google_Product_Category or google_product_category',
        "$SubTestName - prove that the 'AttributeAlias' is set."
    );
    is_deeply($aParameters->[1]->{'ProductID'}, 666, "$SubTestName - prove that the 'ProductID' is set.");
    isa_ok($aParameters->[1]->{'Product'}, 'DE_EPAGES::Product::API::Object::Product');
}
#----------------------------------------------------------------------------------------
sub test_google_product_category_removeUnexpectedCharacters {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $SUT = $self->_createSUT();
    my $Product = $self->_createProduct({
        'Google_Product_Category' => "\"Test\" Category\n second Line",
        'ProductTypeAttributes' => [
            'Google_Product_Category',
        ]
    });

    my $Result = $SUT->google_product_category( $Product );

    is( $Result, 'Test Category', "$SubTestName - prove that the google category is exported." );
    is( WasCalled($SUT, '_Warning'), 0, "$SubTestName - prove that no warning was created." );
}
#----------------------------------------------------------------------------------------
# helpers
#----------------------------------------------------------------------------------------
#----------------------------------------------------------------------------------------
sub _createSUT {
    my $self = shift;

    my $aParameterList = [];
    my $Mockify = Test::Mockify->new(
                   'DE_EPAGES::GoogleBase::API::CSV::GoogleBaseProductsExportDriver',
                   $aParameterList
              );
    $Mockify->spy('_Warning')->when(String(), HashRef());

    return $Mockify->getMockObject();
}

#----------------------------------------------------------------------------------------
sub _createProduct {
    my $self = shift;
    my ($hValues) = @_;

    my $hAttributes = {
        'ID' => '666',
        'Class' => $self->_createProductType($hValues->{'ProductTypeAttributes'}),
        'Google_Product_Category' => $hValues->{'Google_Product_Category'},
        'google_product_category' => $hValues->{'google_product_category'},
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Product::API::Object::Product',
        $hAttributes
    );

    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createProductType {
    my $self = shift;
    my ($aDirectAttributes) = @_;

    my $hAttributes = {
        'Alias' => 'MyShop',
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Product::API::Object::ProductType',
        $hAttributes
    );
    my $Product = $Mockify->getMockObject();
    #This is a hack in order to get the corret result when calling existsAttribute on this class
    foreach my $DirectAttribute (@{$aDirectAttributes}){
        $Product->{'DirectAttributes'}->{$DirectAttribute} = 1;
    }
    return $Product;
}

__PACKAGE__->runScript();