#!/usr/bin/env node
var spawn = require('child_process').spawn,
    path = require('path'),
    phantomjs = require('phantomjs'),
    phantomPath = phantomjs.path,
    testrunner = require('./testrunner'),
    blacklist = require('./blacklist'),

    sorter = function (a, b) {
        let a_split = a.split('|')[1].split('/'),
            a_path = a_split.slice(0, -1),
            b_split = b.split('|')[1].split('/'),
            b_path = b_split.slice(0, -1),
            maxLength,
            _pos;

        maxLength = Math.max(a_path.length, b_path.length);

        if (a_path.join('/') === b_path.join('/')) {
            return (a_split[a_split.length - 1] > b_split[b_split.length - 1]) ? 1 : ((a_split[a_split.length - 1] < b_split[b_split.length - 1]) ? -1 : 0);
        } else {
            for (_pos = 0; _pos < maxLength; _pos++) {

                if (a_path[_pos] === undefined) {
                    return -1;

                } else if (b_path[_pos] === undefined) {
                    return 1;

                } else if (a_path[_pos] > b_path[_pos]) {
                    return 1;

                } else if (a_path[_pos] < b_path[_pos]) {
                    return -1;
                }
            }
        }


    },

    regex = /\..*?\/(ep|de_epages|ckeditor)\//g,
    testFilesPaths = [],

    // parameters for testrunner
    threads = 4,
    timeout = 30,
    debug = false,
    table = false,
    output = true,
    ssl = false,
    useBlacklist = true,
    version,
    storetype,
    vm,

    runtime,
    pathToTest;


//prints instroctions if given parameters are invalid
if(!testrunner.areParamsValid(process.argv)) {
    testrunner.printInstructions();
    process.exit(0);
}

//set arguments for test
version = process.argv[process.argv.indexOf('-v') + 1];
storetype = process.argv[process.argv.indexOf('-storetype') + 1];
vm = process.argv[process.argv.indexOf('-vm') + 1];

if (process.argv.indexOf('-threads') !== -1) {
    threads = process.argv[process.argv.indexOf('-threads') + 1];
}

if (process.argv.indexOf('-timeout') !== -1) {
    timeout = process.argv[process.argv.indexOf('-timeout') + 1];
}

if (process.argv.indexOf('-debug') !== -1) {
    debug = true;
}

if (process.argv.indexOf('-table') !== -1) {
    table = true;
}

if (process.argv.indexOf('-noOutput') !== -1) {
    output = false;
}

if (process.argv.indexOf('-ssl') !== -1) {
    ssl = true;
}

if (process.argv.indexOf('-ignoreBlacklist') !== -1) {
    useBlacklist = false;
}

//get main folder holding tests depending on given parameters
pathToTest = testrunner.getPathToTest(process.argv);

//fill array with pathes to all tests
testFilesPaths = testrunner.getTestFiles([pathToTest]);

// filter blacklisted items
if (useBlacklist) {
    testFilesPaths = testFilesPaths.filter(function(path) {
        return !blacklist.some(function(blacklistedTest) {

            return (path.indexOf(blacklistedTest) !== -1);
        });
    });
}

// recursive testrunner
function runTestsRecursively(testArray, concurrency) {
    var failedTests = [],
        outtimedTests = [],
        runningTests = 0,
        currentTest = 0,
        tabledata = [];

    if (output) {
        console.log('---------------------------------------------------------------------------');
        console.log('Running ' + testArray.length + ' Tests.');
        console.log('---------------------------------------------------------------------------');
        if (table) {
            console.log('||Testfile||Success||Fails||Total||Comments||');
        }
    } else {
        console.log('\n');
    }

    runtime = new Date().getTime();

    return new Promise((resolve, reject) => {
        function runTest(testFilePath, final) {

            // Arguments for the phantom script
            var processArgs = [
                    '--ignore-ssl-errors=true',
                    path.join(__dirname, 'testJSphantom.js'),
                    (ssl ? 'https://' : 'http://') + vm + '/WebRoot/StoreTypes/' + version + '/' + storetype + '/lib/testsuite/qunit.html?test=' + testFilePath,
                    timeout
                ],
                debugData = [],
                test,
                result,
                errorData,
                testBroken,
                debugTimer;


            currentTest++;

            // spawn additional testprocesses, if max thread number not yet reached
            if (runningTests < concurrency && currentTest < testArray.length) {
                runningTests++;
                runTest(testArray[currentTest]);
            }

            // create test process
            test = spawn(phantomPath, processArgs);

            // timeout if no response after 5 times timeout duration
            testBroken = setTimeout(function() {
                test.kill();

                if (!final) {
                    if (debug) {
                        console.log('Warning: Test ' + testFilePath + ' failed. Retrying ...')
                    }

                    runTest(testFilePath, true);
                    return;
                }

                runningTests--;
                outtimedTests.push(testFilePath);
                if (table) {
                    tabledata.push('|' + testFilePath + '| (x) | all | ?? | timeout |');
                } else {
                    console.log('Error: No answer from test ' + testFilePath);
                }
                if (runningTests === 0) {
                    if (table) {
                        console.log(tabledata.sort(sorter).join('\n'));
                    }
                    reject([failedTests, outtimedTests]);
                }
            }, timeout * 5000);


            test.stdout.on('data', (data) => {
                // if no JSON-Object, just print the output
                try {
                    result = JSON.parse(data.toString().split('\n')[0]);
                } catch (e) {
                    if (debug) {
                        clearTimeout(debugTimer);
                        debugData.push(data.toString().replace('\n', ''));

                        debugTimer = setTimeout( () => {
                            console.log('----------------  Debug:  ----------------\n' + debugData.join('\n') + '\n------------------------------------------');
                            debugData.length = 0;
                        }, 1000);
                    }
                    return;
                }

                // on timeout retry this test
                if (!result.success && !final) {
                    if (debug) {
                        console.log('Warning: Test ' + testFilePath + ' failed. Retrying ...')
                    }

                    runTest(testFilePath, true);
                    clearTimeout(testBroken);
                    return;
                }

                // print result
                if (table) {
                    if (result.success) {
                        tabledata.push('|' + result.name + '| (/) | 0 | ' + result.tests + ' | |');
                    } else {
                        switch (result.error) {
                            case 'timeout':
                                outtimedTests.push(result.name);
                                tabledata.push('|' + result.name + '| (x) | all | ?? | timeout |');
                                break;
                            case 'pageload':
                                outtimedTests.push(result.name);
                                tabledata.push('|' + result.name + '| (x) | all | ?? | Couldn`t load page |');
                                break;
                            case 'testfailure':
                                failedTests.push(result.name);
                                try {
                                    errorData = JSON.parse(result.errorData);
                                } catch (e) {
                                    errorData = undefined;
                                }
                                tabledata.push('|' + result.name + '| (x) | ' + result.fails + ' | ' + result.tests + ' | ' + (errorData ? (' --> ' + errorData.join(' \\\\ --> ')) : '') +' |');
                                break;
                        }
                    }
                } else if (output) {
                    if (result.success) {
                        console.log('Completed all ' + result.tests + ' assertions for test ' + result.name.replace(regex, '') + '.');
                    } else {
                        switch (result.error) {
                            case 'timeout':
                                outtimedTests.push(result.name);
                                console.log('Failed test ' + result.name.replace(regex, '') + ' due to timeout.');
                                break;
                            case 'pageload':
                                outtimedTests.push(result.name);
                                console.log('Could not load test ' + result.name.replace(regex, '') + '.');
                                break;
                            case 'testfailure':
                                failedTests.push(result.name);
                                try {
                                    errorData = JSON.parse(result.errorData);
                                } catch (e) {
                                    errorData = undefined;
                                }
                                console.log('Failed ' + result.fails + ' out of ' + result.tests + ' assertions for test ' + result.name.replace(regex, '') + (errorData ? (':\n --> ' + errorData.join('\n --> ')) : '.'));
                                break;
                        }
                    }
                } else {
                    if (!result.success) {
                        if (result.error === 'timeout' || result.error === 'pageload') {
                            outtimedTests.push(result.name);
                        } else {
                            failedTests.push(result.name);
                        }
                    }
                }


                clearTimeout(testBroken);
                // if all tests are run and no process is left running output result, otherwise start with next test.
                if (currentTest >= testArray.length) {
                    runningTests--;
                    if (runningTests === 0) {
                        if (table) {
                            console.log(tabledata.sort(sorter).join('\n'));
                        }
                        if (failedTests.length + outtimedTests.length) {
                            reject([failedTests, outtimedTests]);
                        } else {
                            resolve();
                        }
                    }
                } else {
                    runTest(testArray[currentTest]);
                }
            });

            // print errors
            test.stderr.on('data', (data) => {
                console.log(data.toString().split('\n')[0]);
            });
        }

        // kickoff testing with first test
        runningTests++;
        runTest(testArray[currentTest]);
    });
}

// there are no tests in the array, quit with code -1
if (testFilesPaths.length === 0) {
    process.exit(-1);
}

// start tests;
runTestsRecursively(testFilesPaths, threads)
    .then(() => {
        // on success exit with number of completed tests
        var myRuntime = Math.floor((new Date().getTime() - runtime) / 1000);
        console.log('\n---------------------------------------------------------------------------\n Results: \n---------------------------------------------------------------------------\n');
        console.log('Completed ' + testFilesPaths.length + ' tests successfully in ' + myRuntime + ' seconds.');
        process.exit(0);
    })
    .catch((data) => {
        console.log('\n---------------------------------------------------------------------------\n Results: \n---------------------------------------------------------------------------\n');
        if (Array.isArray(data)) {
            var errors = data[0],
                timeouts = data[1];

            // on error exit with code 0
            var myRuntime = Math.floor((new Date().getTime() - runtime) / 1000);
            console.log('Completed ' + testFilesPaths.length + ' tests in ' + myRuntime + 'seconds with ' + (errors.length + timeouts.length ) + ' failing tests:\n');

            if (errors.length) {
                console.log(errors.sort((a,b) => (a > b) ? 1 : (a < b) ? -1 : 0).join('\n'));
            }

            if (timeouts && timeouts.length > 0) {
                console.log('\nThe following tests failed due to timeout:\n');
                console.log(timeouts.sort((a,b) => (a > b) ? 1 : (a < b) ? -1 : 0).join('\n'));
            }

            process.exit(1);
        } else {
            console.log('Process crashed :', errors);
            process.exit(1);
        }
    });
