#========================================================================================
# package      DE_EPAGES::PayPalPlus::API::Constants
# state        public
# description  constants for cartridge
#========================================================================================
package DE_EPAGES::PayPalPlus::API::Constants;
use base Exporter;

use strict;

our @EXPORT_OK = qw (
    INTERNAL_CARTRIDGE_NAME
    SUPPORTED_CURRENCIES
    ShippingAddressVisibility
    AddressOverride
    APPROVAL_URL
    PAYPALPLUS_STATUS_PENDING
    PAYPALPLUS_STATUS_COMPLETED
    PAYPALPLUS_STATUS_REFUNDED
    PAYPALPLUS_STATUS_PARTIALLY_REFUNDED
    PAYPALPLUS_STATUS_CANCELED
    PAYPALPLUS_STATUS_FAILED
    TRANSSTATUS_PENDING
    TRANSSTATUS_PAID
    TRANSSTATUS_REFUNDED
    TRANSSTATUS_PARTIALLY_REFUNDED
    TRANSSTATUS_CANCELED
    TRANSSTATUS_FAILED
    MAPPER_STATUS_FROM_PAYPAL_TO_EPAGES
    REQUIRED_SHIPPING_ADDRESS_FIELDS
    REQUIRED_SHOP_ADDRESS_FIELDS
    PAYPALPLUS_PAY_UPON_INVOICE
    CLASSIC_CHECKOUT
    MULTISTEP_CHECKOUT
    PAYPALPLUS_IPN_CALLBACK_PATH
    PAYPALPLUS_COOKIE
);

use constant PAYPALPLUS_COOKIE => 'paypalplus_session_v2';

use constant PAYPALPLUS_IPN_CALLBACK_PATH => 'payments/paypalplus/notification';

use constant CLASSIC_CHECKOUT => 0;
use constant MULTISTEP_CHECKOUT => 1;

# This name is used to load objects from database (DON'T CHANGE!)
use constant INTERNAL_CARTRIDGE_NAME => 'PayPalPlus';

# Currencies which are supported by PayPal Plus.
use constant SUPPORTED_CURRENCIES => (qw(
    AUD
    BRL
    CAD
    CHF
    CZK
    DKK
    EUR
    GBP
    HKD
    HUF
    ILS
    JPY
    MXN
    MYR
    NOK
    NZD
    PHP
    PLN
    RUB
    SEK
    SGD
    THB
    TWD
    USD
));


use constant ShippingAddressVisibility => {
    'SHOW_SHIPPING_ADDRESS_ON_PAYPAL_PAGES' => 0,
    'DONT_SHOW_SHIPPING_ADDRESS_ON_PAYPAL_PAGES' => 1,
    'SHOW_SHIPPING_ADDRESS_FROM_BUYERS_ACCOUNT_IF_NOT_PASSED_IN_CALL' => 2,
};

use constant AddressOverride => {
    'SHOW_ADDRESS_FROM_PAYPAL_ACCOUNT_OF_THE_BUYER' => 0,
    'SHOW_ADDRESS_SUPPLIED_IN_THIS_CALL' => 1,
};

use constant APPROVAL_URL => 'approval_url';

use constant PAYPALPLUS_PAY_UPON_INVOICE => 'PAY_UPON_INVOICE';

use constant PAYPALPLUS_STATUS_PENDING => 'pending';
use constant PAYPALPLUS_STATUS_COMPLETED => 'completed';
use constant PAYPALPLUS_STATUS_REFUNDED => 'refunded';
use constant PAYPALPLUS_STATUS_PARTIALLY_REFUNDED => 'partially_refunded';
use constant PAYPALPLUS_STATUS_CANCELED => 'canceled';
use constant PAYPALPLUS_STATUS_FAILED => 'failed';

use constant TRANSSTATUS_PENDING => 'STATUS_PENDING';
use constant TRANSSTATUS_PAID => 'STATUS_PAID';
use constant TRANSSTATUS_REFUNDED => 'STATUS_REFUNDED';
use constant TRANSSTATUS_PARTIALLY_REFUNDED => 'STATUS_PARTIALLY_REFUNDED';
use constant TRANSSTATUS_CANCELED => 'STATUS_CANCELED';
use constant TRANSSTATUS_FAILED => 'STATUS_FAILED';

use constant MAPPER_STATUS_FROM_PAYPAL_TO_EPAGES => {
    PAYPALPLUS_STATUS_PENDING() => TRANSSTATUS_PENDING,
    PAYPALPLUS_STATUS_COMPLETED() => TRANSSTATUS_PAID,
    PAYPALPLUS_STATUS_REFUNDED() => TRANSSTATUS_REFUNDED,
    PAYPALPLUS_STATUS_PARTIALLY_REFUNDED() => TRANSSTATUS_PARTIALLY_REFUNDED,
    PAYPALPLUS_STATUS_CANCELED() => TRANSSTATUS_CANCELED,
    PAYPALPLUS_STATUS_FAILED() => TRANSSTATUS_FAILED
};

# Fields which the merchant needs to set to mandatory in the registration settings
use constant REQUIRED_SHIPPING_ADDRESS_FIELDS => qw ( FirstName LastName City Street Zipcode CountryID );

# Fields which the shop address needs to contain
use constant REQUIRED_SHOP_ADDRESS_FIELDS => qw ( FirstName LastName City Street Zipcode CountryID );

1;