#========================================================================================
# package      DE_EPAGES::Shop::API::WebService::ShopService3
# state        public
#----------------------------------------------------------------------------------------
# description  Provides web service access to shops.
#----------------------------------------------------------------------------------------
# example      use DE_EPAGES::WebService::API::Client;
#               my $FactoryService = DE_EPAGES::WebService::API::Client
#                   ->uri('urn://epages.de/WebService/FactoryService/2004/08')
#                   ->proxy("http://%2fUsers%2f$Login:$Password@localhost:8080/epages/Store.soap");
#               my $ShopID = $FactoryService->objectByPath('/Shops/DemoShop')->result;
#               my $ShopService = DE_EPAGES::WebService::API::Client
#                   ->uri('urn://epages.de/WebService/ShopService/2017/11')
#                   ->proxy("http://%2fUsers%2f$Login:$Password@localhost:8080/epages/Store.soap");
#               $ShopService->registerUnity($ShopID);
#========================================================================================
package DE_EPAGES::Shop::API::WebService::ShopService3;
use base DE_EPAGES::Shop::API::WebService::ShopService2;

use strict;

use DE_EPAGES::Object::API::Factory qw ( LoadObject );

#========================================================================================
# function     setShopAddress
# state        public
#----------------------------------------------------------------------------------------
# syntax       $ShopService->shopService->setShopAddress( $ShopID, $hShopAddress );
#----------------------------------------------------------------------------------------
# description  Sets the shop address.
#----------------------------------------------------------------------------------------
# input        $ShopID | shop id | integer
# $input        $hShopAddress | hash containing the address values | ref.hash
#========================================================================================
sub setShopAddress {
    my $self = shift;
    my ($ShopID, $hAddress) = @_;

    my $Shop = LoadObject( $ShopID );
    my $LanguageID = $Shop->get('LanguageID');
    my $Address = $Shop->get('Address');
    return unless defined $Address;

    for my $Attribute (keys %$hAddress) {
        next unless $Address->class()->existsAttribute($Attribute);
        $Address->set({$Attribute => $hAddress->{$Attribute}}, $LanguageID);
    }
}

1;
