# @(#)yaccpar 1.8 (Berkeley) 01/20/91 (JAKE-P5BP-0.6 04/26/98)
package DE_EPAGES::TLE::API::Parser;
#line 3 "tle.y"
#========================================================================================
# package       DE_EPAGES::TLE::API::Parser
# state         private
#----------------------------------------------------------------------------------------
# description   This module is created by Perl yacc. see tle.y.
#========================================================================================
use base Exporter;

use strict;
our @EXPORT_OK = qw(
    InternalCompile
    InternalAnalyze
);

use DE_EPAGES::TLE::API::LexConstants;
use DE_EPAGES::TLE::API::Lexer      qw ( Lexer );
use DE_EPAGES::TLE::API::Execute    qw ( BuildTree Tree2ByteCode );
use DE_EPAGES::Core::API::Error qw ( ExistsError GetError Error );

sub ErrorDefinition {
    return {
        'GRAMMAR_ERROR' => 'Grammar error at line (#Line) #Message',
        'TLE_ERROR'     => 'TLE error at line (#Line) #Message',
    };
}

# error interface has changed a bit
# the second argument is the reference argument passed to yyparse as argument
sub yyerror {
    my ($msg, $s) = @_;
    Error('TLE_ERROR', {
        'Message'   => $msg,
        'Line'      => $s->{'lineno'},
        'yyparse'   => $s->{'text'},
    });
}

#========================================================================================
# function     InternalCompile
#----------------------------------------------------------------------------------------
# syntax       my $ByteCode = InternalCompile($rPlainText);
#----------------------------------------------------------------------------------------
# description  This procedure parses the given template and creates a perl execution string.
#----------------------------------------------------------------------------------------
# input        $rPlainText | template | ref.string
# return       $ByteCode | the complied template | string
#========================================================================================
sub InternalCompile ($) {
    my ($rPlainText) = @_;
    return Tree2ByteCode({ 'tag' => $BODY, 'text'=> '' }) unless defined $$rPlainText && length($$rPlainText);

    # prepare parser variables
    $yydebug = 0;
    my $s = {
        'text'             => $$rPlainText,
        'lineno'           => 1,
        'lexer_last_token' => $BODY,
        'lexer_context'    => 0,
    };
    my $p = __PACKAGE__->new( \&Lexer, \&yyerror, $yydebug );
    $p->yyparse($s);
    return Tree2ByteCode($s->{'tree'});
}

#========================================================================================
# function     InternalAnalyze
#----------------------------------------------------------------------------------------
# syntax       my $Error = InternalAnalyze($rPlainText);
#----------------------------------------------------------------------------------------
# description  This procedure parses the given template returns the error.
#----------------------------------------------------------------------------------------
# input        $rPlainText | template | ref.string
# return       $Error | error object (or undef) | object
#========================================================================================
sub InternalAnalyze ($) {
    my ($rPlainText) = @_;
    return undef unless length($$rPlainText);

    # prepare parser variables
    $yydebug = 0;
    my $s = {
        'text'             => $$rPlainText,
        'lineno'           => 1,
        'lexer_last_token' => $BODY,
        'lexer_context'    => 0,
    };
    my $p = __PACKAGE__->new( \&Lexer, \&yyerror, $yydebug );
    eval {
        $p->yyparse($s);
    };
    return GetError() if ExistsError();
    return undef;
}

## no critic qw(ProhibitMagicNumbers RequireParenthesesLastChar ProhibitTrailingWhitespace ProhibitInterpolationOfLiterals ProhibitLongLines ProhibitReusedNames ProhibitExcessComplexity)
#line 99 "Parser.pm"
$BODY=257;
$TEMPLATE=258;
$IF=259;
$ELSIF=260;
$ELSE=261;
$ENDIF=262;
$NUMCONSTANT=263;
$STRCONSTANT=264;
$VARIABLE=265;
$FUNCTION=266;
$FUNCTIONNAME=267;
$BLOCK=268;
$ENDBLOCK=269;
$LOOP=270;
$ENDLOOP=271;
$JOIN=272;
$ENDJOIN=273;
$LOCAL=274;
$ENDLOCAL=275;
$WITH=276;
$ENDWITH=277;
$MENU=278;
$ENDMENU=279;
$NAVBAR=280;
$ENDNAVBAR=281;
$WITH_LANGUAGE=282;
$ENDWITH_LANGUAGE=283;
$WITH_ERROR=284;
$ENDWITH_ERROR=285;
$CDATA=286;
$ENDCDATA=287;
$GUI=288;
$ENDGUI=289;
$PARENTHESE=290;
$LIST=291;
$SPACE=292;
$FORMAT=293;
$PERLSCRIPT=294;
$JSSCRIPT=295;
$END_JSSCRIPT=296;
$OR=297;
$AND=298;
$NEQ=299;
$NNE=300;
$EQ=301;
$NE=302;
$NLT=303;
$NLE=304;
$NGT=305;
$NGE=306;
$IN=307;
$NOT=309;
$YYERRCODE=256;
@yylhs = (                                               -1,
    0,    0,    0,    1,    1,    2,    2,    2,    2,    2,
    2,    2,    7,    7,    7,    7,    7,    7,    7,    7,
    7,    7,    7,    7,    7,    7,    4,   10,   10,    9,
    9,    5,    5,    5,    5,    5,    5,    5,    5,    5,
    5,    5,    6,    6,   11,   11,    8,    8,    8,    8,
    8,    8,    8,    8,    8,    8,    8,   12,   12,   12,
   12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
   12,   12,   12,   12,   13,   13,   13,    3,   14,   14,
);
@yylen = (                                                2,
    1,    1,    1,    0,    2,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    8,    0,    2,    0,
    6,    8,    6,    6,    6,    8,    6,    6,    6,    6,
    6,    3,    6,    4,    1,    3,    1,    1,    1,    1,
    1,    1,    3,    2,    2,    5,    6,    3,    3,    3,
    3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
    3,    3,    3,    3,    2,    2,    2,    2,    0,    1,
);
@yydefred = (                                             0,
    2,    3,    0,    0,   12,    0,   23,   24,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   22,    6,    4,   25,   26,   13,   14,   15,   16,
   17,   20,   18,   19,   21,    5,    7,    8,    9,   10,
   11,    0,   80,   78,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   50,   51,    0,
    0,    0,    0,    0,    0,    0,   49,   52,    0,   47,
   48,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   42,    0,    0,    0,    0,    0,
    4,    0,   54,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    4,    0,   44,    0,    0,    4,    4,    0,    4,    4,
    4,    4,    4,    4,    0,    0,   53,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    4,    0,    0,
    0,   43,    4,   34,   33,    4,   35,   37,   38,   39,
   40,   41,    0,   56,    0,    4,    0,    0,    0,   57,
    0,    0,   27,   32,   36,    4,    0,   31,
);
@yydgoto = (                                              3,
    4,   36,   67,   38,   39,   68,   41,   73,  161,  177,
   74,   70,   71,   44,
);
@yysindex = (                                           -56,
    0,    0,    0, 1472,    0,  -23,    0,    0, -285,   17,
   22,   30,   40,   41,   43,   44,   45,   46,   47,   48,
   50,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  504,    0,    0, -206,  504, -173,  504,  504, -164,
  504,  504,  504,  504,  504,  504,  540,    0,    0,   62,
  504,  504,  504,  504,   63,  504,    0,    0,   64,    0,
    0,   60,  161,  -39,   68,  -37,  -32,   69,  -31,  -30,
  -17,  -16,  -15,  -11,    0,  504, -184,   31,   31, -184,
    0,   80,    0,  504,  504,  504,  504,  504,  504,  504,
  504,  504,  504,  504,  504,  504,  504,  504,  504,  504,
    0,  504,    0,  504,  504,    0,    0,  504,    0,    0,
    0,    0,    0,    0,  -10, 1506,    0,  210,  296,  481,
  481,  488,  488,   18,   18,   18,   18,   29,   31,   31,
  -46,  -46,  -46, -184,  589,   -9,  161,   -5,  632,  666,
   96,  700,  967, 1001, 1035, 1069, 1103,    0,   -7,   74,
 -146,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1137,    0,  504,    0, -143, 1404, 1438,    0,
  112, 1472,    0,    0,    0,    0,  589,    0,
);
@yyrindex = (                                            52,
    0,    0,    0,  116,    0,    0,    0,    0,    1,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   -4,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  123,  307,  718,  134,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  -38,   15,  207,
 1174,  364, 1155,  731,  797,  831,  908,  348,  757,  786,
  172,  183,  194,  145, -212,    0,   10,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1540,    0,
 -142,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, -138,    0,    0,    0,    0, -212,    0,
);
@yygindex = (                                             0,
 1480,    0, 1382,    0,    0, 1463,    0, 1775,  -59,    0,
  -33,    0,    0,    0,
);
$YYTABLESIZE=1950;
@yytable = (                                            110,
   79,  113,   58,  116,  114,   58,  114,   43,  117,  119,
  120,  114,  114,  114,   76,   77,   42,   79,   80,   81,
   82,   83,   84,  121,  122,  123,  114,  114,  114,  124,
  158,  162,  114,  114,  114,  163,   45,   79,  114,   45,
   79,   79,   79,   79,   79,   79,   79,   79,   30,   30,
   46,    4,  125,   46,  109,   59,   45,   72,   59,  107,
  105,   46,  106,  110,  108,  109,    1,  109,    2,   47,
  107,  105,  107,  106,  110,  108,  110,  108,  146,   48,
   49,  148,   50,   51,   52,   53,   54,   55,    4,   56,
   75,    4,    4,    4,    4,    4,    4,    4,    4,   78,
  109,   86,   91,  112,  111,  107,  105,   93,  106,  110,
  108,  115,  118,  175,  176,    1,  109,  174,  183,   28,
  127,  107,  105,   29,  106,  110,  108,  188,    0,    0,
    0,    0,  109,    0,    0,    0,  166,  107,  105,    0,
  106,  110,  108,    0,    0,    0,    0,    0,  109,    0,
    0,    0,  186,  107,  105,    0,  106,  110,  108,   55,
    0,    0,    0,   55,   55,   55,   55,   55,   55,   55,
   75,    0,    0,    0,   75,   75,   75,   75,   75,   75,
   75,   74,    0,    0,    0,   74,   74,   74,   74,   74,
   74,   74,    0,    0,    0,    0,    0,  109,    0,    0,
    0,    0,  107,  105,    0,  106,  110,  108,   71,    0,
    0,    0,   71,   71,   71,   71,   71,    0,   71,   72,
    0,    0,    0,   72,   72,   72,   72,   72,    0,   72,
   73,    0,    0,    0,   73,   73,   73,   73,   73,    0,
   73,    0,    0,    0,    0,   93,  109,   62,    0,    0,
   62,  107,  105,    0,  106,  110,  108,   79,   58,   79,
   79,   79,   79,   79,   79,   79,   79,   79,   79,   79,
   79,   79,   79,   79,   79,   79,   79,   79,   79,   79,
   79,   79,   79,   79,   79,   79,    0,   79,   79,   79,
    0,    0,   79,    0,   79,   79,   79,   79,   79,   79,
   79,   79,   79,   79,   79,   79,   79,   79,    4,   93,
    4,   59,   59,    0,    4,    4,    4,    4,    4,    4,
   93,    4,   93,    4,  104,    4,    0,    4,    0,    4,
    0,    4,  109,    4,    0,    4,    0,  107,  105,    4,
  106,  110,  108,    4,    0,    4,    4,   77,    0,   77,
   77,   77,    0,    0,    4,   93,    4,    0,    0,    0,
   94,   95,   96,   97,   98,   99,  100,  101,  102,  103,
  104,   93,    0,    0,    0,    0,   94,   95,   96,   97,
   98,   99,  100,  101,  102,  103,  104,   93,   68,    0,
    0,   68,   94,   95,   96,   97,   98,   99,  100,  101,
  102,  103,  104,   93,   60,    0,    0,   60,   94,   95,
   96,   97,   98,   99,  100,  101,  102,  103,  104,   55,
   55,   55,   55,   55,   55,   55,   55,   55,   55,   55,
   75,   75,   75,   75,   75,   75,   75,   75,   75,   75,
   75,   74,   74,   74,   74,   74,   74,   74,   74,   74,
   74,   74,   93,    0,    0,    0,    0,   94,   95,   96,
   97,   98,   99,  100,  101,  102,  103,  104,   71,   71,
   71,   71,   71,   71,   71,   71,   71,   71,   71,   72,
   72,   72,   72,   72,   72,   72,   72,   72,   72,   72,
   73,   73,   73,   73,   73,   73,   73,   73,   73,   73,
   73,   93,    0,   62,   62,   62,   62,   95,   96,   97,
   98,   99,  100,  101,  102,  103,  104,  109,    0,    0,
    0,    0,  107,  105,  109,  106,  110,  108,    0,  107,
  105,    0,  106,  110,  108,    0,    0,    0,    0,    0,
    0,    0,    0,   66,    0,    0,   62,    0,   63,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   31,    0,    0,   33,
   34,   29,   27,   35,   28,   32,   30,   93,    0,    0,
    0,    0,    0,    0,   96,   97,   98,   99,  100,  101,
  102,  103,  104,   77,   77,   77,   77,   77,   77,   77,
   77,   77,   77,   77,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   31,   65,    0,   33,   34,
   29,   27,   35,   28,   32,   30,    0,    0,    0,    0,
    0,    0,    0,    0,   68,   68,   68,   68,   68,   68,
   68,   68,   68,   68,   68,    0,    0,    0,    0,    0,
   60,   60,   60,   60,   60,   60,    0,    0,   31,    0,
    0,   33,   34,   29,   27,   35,   28,   32,   30,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   31,    0,    0,   33,   34,   29,   27,   35,
   28,   32,   30,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   31,    0,    0,   33,
   34,   29,   27,   35,   28,   32,   30,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   76,    0,
   76,   76,   76,    0,    0,    0,   58,   59,    9,   10,
   11,   64,   93,    0,   64,    0,    0,    0,    0,   93,
    0,   98,   99,  100,  101,  102,  103,  104,    0,   60,
  100,  101,  102,  103,  104,   61,    5,   69,    6,   69,
   69,   69,    7,    8,    9,   10,   11,   12,    0,   13,
    0,   14,   64,   15,    0,   16,    0,   17,    0,   18,
    0,   19,    0,   20,    0,    0,   70,   21,   70,   70,
   70,   22,    0,   23,   24,   85,    0,   65,    0,    0,
   65,    0,   25,    0,   26,    5,    0,    6,  160,    0,
    0,    7,    8,    9,   10,   11,   12,    0,   13,    0,
   14,    0,   15,    0,   16,    0,   17,    0,   18,    0,
   19,   66,   20,    0,   66,    0,   21,    0,    0,    0,
   22,    0,   23,   24,    0,    0,    0,    0,    5,    0,
    6,   25,    0,   26,    7,    8,    9,   10,   11,   12,
    0,   13,  164,   14,    0,   15,    0,   16,    0,   17,
    0,   18,    0,   19,    0,   20,    0,    0,    0,   21,
    0,    0,    5,   22,    6,   23,   24,    0,    7,    8,
    9,   10,   11,   12,   25,   13,   26,   14,  165,   15,
    0,   16,    0,   17,    0,   18,    0,   19,   67,   20,
    0,   67,    0,   21,    0,    0,    5,   22,    6,   23,
   24,    0,    7,    8,    9,   10,   11,   12,   25,   13,
   26,   14,    0,   15,    0,   16,  167,   17,    0,   18,
    0,   19,    0,   20,    0,    0,    0,   21,    0,    0,
    0,   22,    0,   23,   24,    0,    0,    0,    0,    0,
    0,    0,   25,   31,   26,    0,   33,   34,   29,   27,
   35,   28,   32,   30,   76,   76,   76,   76,   76,   76,
   76,   76,   76,   76,   76,    0,    0,   64,   64,   64,
   64,   64,   64,   64,   64,   64,   64,   31,    0,    0,
   33,   34,   29,   27,   35,   28,   32,   30,    0,    0,
    0,    0,    0,   69,   69,   69,   69,   69,   69,   69,
   69,   69,   69,   69,    0,    0,    0,    0,    0,    0,
    0,   31,    0,    0,   33,   34,   29,   27,   35,   28,
   32,   30,   70,   70,   70,   70,   70,   70,   70,   70,
   70,   70,   70,   65,   65,   65,   65,   65,   65,   65,
   65,   65,   65,    0,    0,   31,    0,    0,   33,   34,
   29,   27,   35,   28,   32,   30,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   66,   66,   66,
   66,   66,   66,   66,   66,   66,   66,    0,    0,   31,
    0,    0,   33,   34,   29,   27,   35,   28,   32,   30,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   31,    0,    0,   33,   34,   29,   27,
   35,   28,   32,   30,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   61,    0,    0,   61,    0,
    0,    0,    0,    0,   67,   67,   67,   67,   67,   67,
   67,   67,   67,   67,   63,    0,    0,   63,    0,    0,
    0,    0,    0,    5,    0,    6,    0,    0,    0,    7,
    8,    9,   10,   11,   12,    0,   13,    0,   14,    0,
   15,    0,   16,    0,   17,  168,   18,    0,   19,    0,
   20,    0,    0,    0,   21,    0,    0,    5,   22,    6,
   23,   24,    0,    7,    8,    9,   10,   11,   12,   25,
   13,   26,   14,    0,   15,    0,   16,    0,   17,    0,
   18,  169,   19,    0,   20,    0,    0,    0,   21,    0,
    0,    5,   22,    6,   23,   24,    0,    7,    8,    9,
   10,   11,   12,   25,   13,   26,   14,    0,   15,    0,
   16,    0,   17,    0,   18,    0,   19,  170,   20,    0,
    0,    0,   21,    0,    0,    5,   22,    6,   23,   24,
    0,    7,    8,    9,   10,   11,   12,   25,   13,   26,
   14,    0,   15,    0,   16,    0,   17,    0,   18,    0,
   19,    0,   20,  171,    0,    0,   21,    0,    0,    5,
   22,    6,   23,   24,    0,    7,    8,    9,   10,   11,
   12,   25,   13,   26,   14,    0,   15,    0,   16,    0,
   17,    0,   18,    0,   19,   37,   20,    0,    0,    0,
   21,  172,    0,    5,   22,    6,   23,   24,    0,    7,
    8,    9,   10,   11,   12,   25,   13,   26,   14,    0,
   15,    0,   16,    0,   17,    0,   18,    0,   19,    0,
   20,    0,    0,  180,   21,    0,    0,    0,   22,    0,
   23,   24,    0,    0,    0,    0,    0,    0,   37,   25,
   31,   26,    0,   33,   34,   29,   27,   35,   28,   32,
   30,   61,   61,   61,   61,   61,   61,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   40,    0,    0,    0,
   63,   63,   63,   63,   31,    0,    0,   33,   34,   29,
   27,   35,   28,   32,   30,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   57,    0,    0,    0,   37,   31,    0,
    0,   33,   34,   29,   27,   35,   28,   32,   30,   40,
    0,    0,    0,    0,    0,    0,   37,    0,    0,    0,
   37,   37,    0,   37,   37,   37,   37,   37,   37,    0,
    0,    0,   31,    0,    0,   33,  159,   29,   27,   35,
   28,   32,   30,    0,   37,    0,    0,    0,    0,   37,
   37,    0,    0,   37,    0,    0,    0,    0,   37,    0,
  126,    0,    0,    0,    0,    0,   19,    0,    0,   19,
   19,   19,   19,   19,   19,   19,   19,    0,   40,    0,
  145,    0,    0,    0,    0,  149,  150,    0,  152,  153,
  154,  155,  156,  157,    0,    0,    0,   40,    0,    0,
    0,   40,   40,    0,   40,   40,   40,   40,   40,   40,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   40,    0,  173,    0,    0,
   40,   40,  178,    0,   40,  179,    0,    0,    0,   40,
    0,    0,    0,    0,    0,  182,    0,    0,    0,    0,
    5,    0,    6,    0,    0,  187,    7,    8,    9,   10,
   11,   12,  184,   13,    0,   14,    0,   15,    0,   16,
    0,   17,    0,   18,    0,   19,    0,   20,    0,    0,
    0,   21,    0,    0,    5,   22,    6,   23,   24,    0,
    7,    8,    9,   10,   11,   12,   25,   13,   26,   14,
    0,   15,  185,   16,    0,   17,    0,   18,    0,   19,
    0,   20,    0,    0,    0,   21,    0,    0,    5,   22,
    6,   23,   24,    0,    7,    8,    9,   10,   11,   12,
   25,   13,   26,   14,    0,   15,    0,   16,    0,   17,
    0,   18,    0,   19,    0,   20,    0,    0,    0,   21,
    0,    0,    5,   22,    6,   23,   24,    0,    7,    8,
    9,   10,   11,   12,   25,   13,   26,   14,    0,   15,
    0,   16,    0,   17,    0,   18,    0,   19,    0,   20,
    0,    0,    0,   21,    0,    0,   19,   22,   19,   23,
   24,    0,   19,   19,   19,   19,   19,   19,   25,   19,
   26,   19,    0,   19,    0,   19,   69,   19,    0,   19,
    0,   19,    0,   19,    0,    0,    0,   19,    0,    0,
    0,   19,    0,   19,   19,   87,   88,   89,   90,    0,
   92,    0,   19,    0,   19,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  128,  129,
  130,  131,  132,  133,  134,  135,  136,  137,  138,  139,
  140,  141,  142,  143,  144,    0,    0,    0,  147,    0,
    0,    0,  151,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  181,
);
@yycheck = (                                             46,
    0,   41,   41,   41,   44,   44,   44,  293,   41,   41,
   41,   44,   44,   44,   48,   49,   40,   51,   52,   53,
   54,   55,   56,   41,   41,   41,   44,   44,   44,   41,
   41,   41,   44,   44,   44,   41,   41,   37,   44,   44,
   40,   41,   42,   43,   44,   45,   46,   47,  261,  262,
   41,    0,   86,   44,   37,   41,   40,  264,   44,   42,
   43,   40,   45,   46,   47,   37,  123,   37,  125,   40,
   42,   43,   42,   45,   46,   47,   46,   47,  112,   40,
   40,  115,   40,   40,   40,   40,   40,   40,   37,   40,
  264,   40,   41,   42,   43,   44,   45,   46,   47,  264,
   37,   40,   40,   44,   41,   42,   43,  292,   45,   46,
   47,   44,   44,   40,  261,    0,   37,  125,  262,  262,
   41,   42,   43,  262,   45,   46,   47,  187,   -1,   -1,
   -1,   -1,   37,   -1,   -1,   -1,   41,   42,   43,   -1,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   37,   -1,
   -1,   -1,   41,   42,   43,   -1,   45,   46,   47,   37,
   -1,   -1,   -1,   41,   42,   43,   44,   45,   46,   47,
   37,   -1,   -1,   -1,   41,   42,   43,   44,   45,   46,
   47,   37,   -1,   -1,   -1,   41,   42,   43,   44,   45,
   46,   47,   -1,   -1,   -1,   -1,   -1,   37,   -1,   -1,
   -1,   -1,   42,   43,   -1,   45,   46,   47,   37,   -1,
   -1,   -1,   41,   42,   43,   44,   45,   -1,   47,   37,
   -1,   -1,   -1,   41,   42,   43,   44,   45,   -1,   47,
   37,   -1,   -1,   -1,   41,   42,   43,   44,   45,   -1,
   47,   -1,   -1,   -1,   -1,  292,   37,   41,   -1,   -1,
   44,   42,   43,   -1,   45,   46,   47,  257,  297,  259,
  260,  261,  262,  263,  264,  265,  266,  267,  268,  269,
  270,  271,  272,  273,  274,  275,  276,  277,  278,  279,
  280,  281,  282,  283,  284,  285,   -1,  287,  288,  289,
   -1,   -1,  292,   -1,  294,  295,  296,  297,  298,  299,
  300,  301,  302,  303,  304,  305,  306,  307,  257,  292,
  259,  297,  298,   -1,  263,  264,  265,  266,  267,  268,
  292,  270,  292,  272,  307,  274,   -1,  276,   -1,  278,
   -1,  280,   37,  282,   -1,  284,   -1,   42,   43,  288,
   45,   46,   47,  292,   -1,  294,  295,   41,   -1,   43,
   44,   45,   -1,   -1,  303,  292,  305,   -1,   -1,   -1,
  297,  298,  299,  300,  301,  302,  303,  304,  305,  306,
  307,  292,   -1,   -1,   -1,   -1,  297,  298,  299,  300,
  301,  302,  303,  304,  305,  306,  307,  292,   41,   -1,
   -1,   44,  297,  298,  299,  300,  301,  302,  303,  304,
  305,  306,  307,  292,   41,   -1,   -1,   44,  297,  298,
  299,  300,  301,  302,  303,  304,  305,  306,  307,  297,
  298,  299,  300,  301,  302,  303,  304,  305,  306,  307,
  297,  298,  299,  300,  301,  302,  303,  304,  305,  306,
  307,  297,  298,  299,  300,  301,  302,  303,  304,  305,
  306,  307,  292,   -1,   -1,   -1,   -1,  297,  298,  299,
  300,  301,  302,  303,  304,  305,  306,  307,  297,  298,
  299,  300,  301,  302,  303,  304,  305,  306,  307,  297,
  298,  299,  300,  301,  302,  303,  304,  305,  306,  307,
  297,  298,  299,  300,  301,  302,  303,  304,  305,  306,
  307,  292,   -1,  297,  298,  299,  300,  298,  299,  300,
  301,  302,  303,  304,  305,  306,  307,   37,   -1,   -1,
   -1,   -1,   42,   43,   37,   45,   46,   47,   -1,   42,
   43,   -1,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   40,   -1,   -1,   43,   -1,   45,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   37,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,  292,   -1,   -1,
   -1,   -1,   -1,   -1,  299,  300,  301,  302,  303,  304,
  305,  306,  307,  297,  298,  299,  300,  301,  302,  303,
  304,  305,  306,  307,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   37,  123,   -1,   40,   41,
   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  297,  298,  299,  300,  301,  302,
  303,  304,  305,  306,  307,   -1,   -1,   -1,   -1,   -1,
  297,  298,  299,  300,  301,  302,   -1,   -1,   37,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   37,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   37,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   41,   -1,
   43,   44,   45,   -1,   -1,   -1,  263,  264,  265,  266,
  267,   41,  292,   -1,   44,   -1,   -1,   -1,   -1,  292,
   -1,  301,  302,  303,  304,  305,  306,  307,   -1,  286,
  303,  304,  305,  306,  307,  292,  257,   41,  259,   43,
   44,   45,  263,  264,  265,  266,  267,  268,   -1,  270,
   -1,  272,  309,  274,   -1,  276,   -1,  278,   -1,  280,
   -1,  282,   -1,  284,   -1,   -1,   41,  288,   43,   44,
   45,  292,   -1,  294,  295,  296,   -1,   41,   -1,   -1,
   44,   -1,  303,   -1,  305,  257,   -1,  259,  260,   -1,
   -1,  263,  264,  265,  266,  267,  268,   -1,  270,   -1,
  272,   -1,  274,   -1,  276,   -1,  278,   -1,  280,   -1,
  282,   41,  284,   -1,   44,   -1,  288,   -1,   -1,   -1,
  292,   -1,  294,  295,   -1,   -1,   -1,   -1,  257,   -1,
  259,  303,   -1,  305,  263,  264,  265,  266,  267,  268,
   -1,  270,  271,  272,   -1,  274,   -1,  276,   -1,  278,
   -1,  280,   -1,  282,   -1,  284,   -1,   -1,   -1,  288,
   -1,   -1,  257,  292,  259,  294,  295,   -1,  263,  264,
  265,  266,  267,  268,  303,  270,  305,  272,  273,  274,
   -1,  276,   -1,  278,   -1,  280,   -1,  282,   41,  284,
   -1,   44,   -1,  288,   -1,   -1,  257,  292,  259,  294,
  295,   -1,  263,  264,  265,  266,  267,  268,  303,  270,
  305,  272,   -1,  274,   -1,  276,  277,  278,   -1,  280,
   -1,  282,   -1,  284,   -1,   -1,   -1,  288,   -1,   -1,
   -1,  292,   -1,  294,  295,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  303,   37,  305,   -1,   40,   41,   42,   43,
   44,   45,   46,   47,  297,  298,  299,  300,  301,  302,
  303,  304,  305,  306,  307,   -1,   -1,  297,  298,  299,
  300,  301,  302,  303,  304,  305,  306,   37,   -1,   -1,
   40,   41,   42,   43,   44,   45,   46,   47,   -1,   -1,
   -1,   -1,   -1,  297,  298,  299,  300,  301,  302,  303,
  304,  305,  306,  307,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   37,   -1,   -1,   40,   41,   42,   43,   44,   45,
   46,   47,  297,  298,  299,  300,  301,  302,  303,  304,
  305,  306,  307,  297,  298,  299,  300,  301,  302,  303,
  304,  305,  306,   -1,   -1,   37,   -1,   -1,   40,   41,
   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  297,  298,  299,
  300,  301,  302,  303,  304,  305,  306,   -1,   -1,   37,
   -1,   -1,   40,   41,   42,   43,   44,   45,   46,   47,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   37,   -1,   -1,   40,   41,   42,   43,
   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   41,   -1,   -1,   44,   -1,
   -1,   -1,   -1,   -1,  297,  298,  299,  300,  301,  302,
  303,  304,  305,  306,   41,   -1,   -1,   44,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,  263,
  264,  265,  266,  267,  268,   -1,  270,   -1,  272,   -1,
  274,   -1,  276,   -1,  278,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,   -1,  288,   -1,   -1,  257,  292,  259,
  294,  295,   -1,  263,  264,  265,  266,  267,  268,  303,
  270,  305,  272,   -1,  274,   -1,  276,   -1,  278,   -1,
  280,  281,  282,   -1,  284,   -1,   -1,   -1,  288,   -1,
   -1,  257,  292,  259,  294,  295,   -1,  263,  264,  265,
  266,  267,  268,  303,  270,  305,  272,   -1,  274,   -1,
  276,   -1,  278,   -1,  280,   -1,  282,  283,  284,   -1,
   -1,   -1,  288,   -1,   -1,  257,  292,  259,  294,  295,
   -1,  263,  264,  265,  266,  267,  268,  303,  270,  305,
  272,   -1,  274,   -1,  276,   -1,  278,   -1,  280,   -1,
  282,   -1,  284,  285,   -1,   -1,  288,   -1,   -1,  257,
  292,  259,  294,  295,   -1,  263,  264,  265,  266,  267,
  268,  303,  270,  305,  272,   -1,  274,   -1,  276,   -1,
  278,   -1,  280,   -1,  282,    4,  284,   -1,   -1,   -1,
  288,  289,   -1,  257,  292,  259,  294,  295,   -1,  263,
  264,  265,  266,  267,  268,  303,  270,  305,  272,   -1,
  274,   -1,  276,   -1,  278,   -1,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,  288,   -1,   -1,   -1,  292,   -1,
  294,  295,   -1,   -1,   -1,   -1,   -1,   -1,   57,  303,
   37,  305,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,  297,  298,  299,  300,  301,  302,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,    4,   -1,   -1,   -1,
  297,  298,  299,  300,   37,   -1,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   24,   -1,   -1,   -1,  126,   37,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   57,
   -1,   -1,   -1,   -1,   -1,   -1,  145,   -1,   -1,   -1,
  149,  150,   -1,  152,  153,  154,  155,  156,  157,   -1,
   -1,   -1,   37,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,  173,   -1,   -1,   -1,   -1,  178,
  179,   -1,   -1,  182,   -1,   -1,   -1,   -1,  187,   -1,
   91,   -1,   -1,   -1,   -1,   -1,   37,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,  126,   -1,
  111,   -1,   -1,   -1,   -1,  116,  117,   -1,  119,  120,
  121,  122,  123,  124,   -1,   -1,   -1,  145,   -1,   -1,
   -1,  149,  150,   -1,  152,  153,  154,  155,  156,  157,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  173,   -1,  158,   -1,   -1,
  178,  179,  163,   -1,  182,  166,   -1,   -1,   -1,  187,
   -1,   -1,   -1,   -1,   -1,  176,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  186,  263,  264,  265,  266,
  267,  268,  269,  270,   -1,  272,   -1,  274,   -1,  276,
   -1,  278,   -1,  280,   -1,  282,   -1,  284,   -1,   -1,
   -1,  288,   -1,   -1,  257,  292,  259,  294,  295,   -1,
  263,  264,  265,  266,  267,  268,  303,  270,  305,  272,
   -1,  274,  275,  276,   -1,  278,   -1,  280,   -1,  282,
   -1,  284,   -1,   -1,   -1,  288,   -1,   -1,  257,  292,
  259,  294,  295,   -1,  263,  264,  265,  266,  267,  268,
  303,  270,  305,  272,   -1,  274,   -1,  276,   -1,  278,
   -1,  280,   -1,  282,   -1,  284,   -1,   -1,   -1,  288,
   -1,   -1,  257,  292,  259,  294,  295,   -1,  263,  264,
  265,  266,  267,  268,  303,  270,  305,  272,   -1,  274,
   -1,  276,   -1,  278,   -1,  280,   -1,  282,   -1,  284,
   -1,   -1,   -1,  288,   -1,   -1,  257,  292,  259,  294,
  295,   -1,  263,  264,  265,  266,  267,  268,  303,  270,
  305,  272,   -1,  274,   -1,  276,   42,  278,   -1,  280,
   -1,  282,   -1,  284,   -1,   -1,   -1,  288,   -1,   -1,
   -1,  292,   -1,  294,  295,   61,   62,   63,   64,   -1,
   66,   -1,  303,   -1,  305,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   94,   95,
   96,   97,   98,   99,  100,  101,  102,  103,  104,  105,
  106,  107,  108,  109,  110,   -1,   -1,   -1,  114,   -1,
   -1,   -1,  118,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  175,
);
$YYFINAL=3;
#ifndef YYDEBUG
#define YYDEBUG 0
#endif
$YYMAXTOKEN=309;
#if YYDEBUG
@yyname = (
"end-of-file",'','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','',
'','','',"'%'",'','',"'('","')'","'*'","'+'","','","'-'","'.'","'/'",'','','','','','','','',
'','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','',
'','','','','','','','','','','','','','','','','','','','','','','','','','','',"'{'",'',"'}'",'','','','','','',
'','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','',
'','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','',
'','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','',
'','','','','',"BODY","TEMPLATE","IF","ELSIF","ELSE","ENDIF","NUMCONSTANT",
"STRCONSTANT","VARIABLE","FUNCTION","FUNCTIONNAME","BLOCK","ENDBLOCK","LOOP",
"ENDLOOP","JOIN","ENDJOIN","LOCAL","ENDLOCAL","WITH","ENDWITH","MENU","ENDMENU",
"NAVBAR","ENDNAVBAR","WITH_LANGUAGE","ENDWITH_LANGUAGE","WITH_ERROR",
"ENDWITH_ERROR","CDATA","ENDCDATA","GUI","ENDGUI","PARENTHESE","LIST","SPACE",
"FORMAT","PERLSCRIPT","JSSCRIPT","END_JSSCRIPT","OR","AND","NEQ","NNE","EQ",
"NE","NLT","NLE","NGT","NGE","IN","\"->\"","NOT",
);
@yyrule = (
"\$accept : start",
"start : template",
"start : '{'",
"start : '}'",
"template :",
"template : template templatebody",
"templatebody : PERLSCRIPT",
"templatebody : formvariable",
"templatebody : if",
"templatebody : block",
"templatebody : function",
"templatebody : body",
"templatebody : BODY",
"body : '+'",
"body : '-'",
"body : '*'",
"body : '/'",
"body : '%'",
"body : '('",
"body : ')'",
"body : '.'",
"body : ','",
"body : SPACE",
"body : NUMCONSTANT",
"body : STRCONSTANT",
"body : NLT",
"body : NGT",
"if : IF '(' expr ')' template elsif else ENDIF",
"else :",
"else : ELSE template",
"elsif :",
"elsif : ELSIF '(' expr ')' template elsif",
"block : BLOCK '(' STRCONSTANT ',' expr_list ')' template ENDBLOCK",
"block : JOIN '(' expr_list ')' template ENDJOIN",
"block : LOOP '(' expr_list ')' template ENDLOOP",
"block : WITH '(' expr_list ')' template ENDWITH",
"block : LOCAL '(' STRCONSTANT ',' expr ')' template ENDLOCAL",
"block : MENU '(' expr_list ')' template ENDMENU",
"block : NAVBAR '(' expr_list ')' template ENDNAVBAR",
"block : WITH_LANGUAGE '(' expr_list ')' template ENDWITH_LANGUAGE",
"block : WITH_ERROR '(' expr_list ')' template ENDWITH_ERROR",
"block : GUI '(' expr_list ')' template ENDGUI",
"block : JSSCRIPT template END_JSSCRIPT",
"function : FUNCTION '(' STRCONSTANT ',' expr_list ')'",
"function : FUNCTIONNAME '(' expr_list ')'",
"expr_list : expr",
"expr_list : expr_list ',' expr",
"expr : binop",
"expr : unop",
"expr : formvariable",
"expr : NUMCONSTANT",
"expr : STRCONSTANT",
"expr : function",
"expr : '(' expr ')'",
"expr : expr SPACE",
"expr : SPACE expr",
"expr : '{' '(' template ')' '}'",
"expr : CDATA '(' expr_list ')' template ENDCDATA",
"binop : expr OR expr",
"binop : expr AND expr",
"binop : expr EQ expr",
"binop : expr NE expr",
"binop : expr NEQ expr",
"binop : expr NNE expr",
"binop : expr NLT expr",
"binop : expr NLE expr",
"binop : expr NGT expr",
"binop : expr NGE expr",
"binop : expr IN expr",
"binop : expr '+' expr",
"binop : expr '-' expr",
"binop : expr '*' expr",
"binop : expr '/' expr",
"binop : expr '%' expr",
"binop : expr '.' expr",
"unop : NOT expr",
"unop : '-' expr",
"unop : '+' expr",
"formvariable : VARIABLE format",
"format :",
"format : FORMAT",
);
#endif
use fields qw(yylex yyerror yydebug yynerrs yyerrflag yym
              yyn yyss yyssp yyvs yyvsp yystate yyval
              yylval yychar yys);
sub yyclearin {
  my DE_EPAGES::TLE::API::Parser $p;
  ($p) = @_;
  $p->{yychar} = -1;
}
sub yyerrok {
  my DE_EPAGES::TLE::API::Parser $p;
  ($p) = @_;
  $p->{yyerrflag} = 0;
}
sub new {
  my $class = shift;
  my DE_EPAGES::TLE::API::Parser $p = fields::new($class);
  ($p->{yylex}, $p->{yyerror}, $p->{yydebug}) = @_;
  return $p;
}
sub YYERROR {
  my DE_EPAGES::TLE::API::Parser $p;
  ($p) = @_;
  ++$p->{yynerrs};
  $p->yy_err_recover;
}
sub yy_err_recover {
  my DE_EPAGES::TLE::API::Parser $p;
  ($p) = @_;
  if ($p->{yyerrflag} < 3)
  {
    $p->{yyerrflag} = 3;
    while (1)
    {
      if (($p->{yyn} = $yysindex[$p->{yyss}->[$p->{yyssp}]]) && 
          ($p->{yyn} += $YYERRCODE) >= 0 && 
          $p->{yyn} <= $#yycheck &&
          $yycheck[$p->{yyn}] == $YYERRCODE)
      {
        warn("yydebug: state " . 
                     $p->{yyss}->[$p->{yyssp}] . 
                     ", error recovery shifting to state" . 
                     $yytable[$p->{yyn}] . "\n") 
                       if $p->{yydebug};
        $p->{yyss}->[++$p->{yyssp}] = 
          $p->{yystate} = $yytable[$p->{yyn}];
        $p->{yyvs}->[++$p->{yyvsp}] = $p->{yylval};
        next yyloop;
      }
      else
      {
        warn("yydebug: error recovery discarding state ".
              $p->{yyss}->[$p->{yyssp}]. "\n") 
                if $p->{yydebug};
        return(undef) if $p->{yyssp} <= 0;
        --$p->{yyssp};
        --$p->{yyvsp};
      }
    }
  }
  else
  {
    return (undef) if $p->{yychar} == 0;
    if ($p->{yydebug})
    {
      $p->{yys} = '';
      if ($p->{yychar} <= $YYMAXTOKEN) { $p->{yys} = 
        $yyname[$p->{yychar}]; }
      if (!$p->{yys}) { $p->{yys} = 'illegal-symbol'; }
      warn("yydebug: state " . $p->{yystate} . 
                   ", error recovery discards " . 
                   "token " . $p->{yychar} . "(" . 
                   $p->{yys} . ")\n");
    }
    $p->{yychar} = -1;
    next yyloop;
  }
0;
} # yy_err_recover

sub yyparse {
  my DE_EPAGES::TLE::API::Parser $p;
  my $s;
  ($p, $s) = @_;
  my %ActiontoExec = ( 
'1' => sub 
#line 123 "tle.y"
{  my $p = shift;  $s->{'tree'} = $p->{yyval}; 
},
'4' => sub 
#line 126 "tle.y"
{  my $p = shift;  $p->{yyval} = undef; 
},
'5' => sub 
#line 127 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($TEMPLATE, [$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-1], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'11' => sub 
#line 134 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($BODY, [$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'27' => sub 
#line 145 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($IF, [$p->{yyvs}->[$p->{yyvsp}-7],$p->{yyvs}->[$p->{yyvsp}-6],$p->{yyvs}->[$p->{yyvsp}-5],$p->{yyvs}->[$p->{yyvsp}-4],$p->{yyvs}->[$p->{yyvsp}-3],$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-5], $p->{yyvs}->[$p->{yyvsp}-3], $p->{yyvs}->[$p->{yyvsp}-2], $p->{yyvs}->[$p->{yyvsp}-1]); 
},
'28' => sub 
#line 147 "tle.y"
{  my $p = shift;  $p->{yyval} = undef; 
},
'29' => sub 
#line 148 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($ELSE, [$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'30' => sub 
#line 150 "tle.y"
{  my $p = shift;  $p->{yyval} = undef; 
},
'31' => sub 
#line 152 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($ELSIF, [$p->{yyvs}->[$p->{yyvsp}-5],$p->{yyvs}->[$p->{yyvsp}-4],$p->{yyvs}->[$p->{yyvsp}-3],$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-3], $p->{yyvs}->[$p->{yyvsp}-1], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'32' => sub 
#line 155 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($BLOCK, [$p->{yyvs}->[$p->{yyvsp}-7],$p->{yyvs}->[$p->{yyvsp}-6],$p->{yyvs}->[$p->{yyvsp}-5],$p->{yyvs}->[$p->{yyvsp}-4],$p->{yyvs}->[$p->{yyvsp}-3],$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-5], $p->{yyvs}->[$p->{yyvsp}-3], $p->{yyvs}->[$p->{yyvsp}-1]); 
},
'33' => sub 
#line 157 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($BLOCK, [$p->{yyvs}->[$p->{yyvsp}-5],$p->{yyvs}->[$p->{yyvsp}-4],$p->{yyvs}->[$p->{yyvsp}-3],$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], 'JOIN', $p->{yyvs}->[$p->{yyvsp}-3], $p->{yyvs}->[$p->{yyvsp}-1] ); 
},
'34' => sub 
#line 159 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($BLOCK, [$p->{yyvs}->[$p->{yyvsp}-5],$p->{yyvs}->[$p->{yyvsp}-4],$p->{yyvs}->[$p->{yyvsp}-3],$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], 'LOOP', $p->{yyvs}->[$p->{yyvsp}-3], $p->{yyvs}->[$p->{yyvsp}-1] ); 
},
'35' => sub 
#line 161 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($BLOCK, [$p->{yyvs}->[$p->{yyvsp}-5],$p->{yyvs}->[$p->{yyvsp}-4],$p->{yyvs}->[$p->{yyvsp}-3],$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], 'WITH', $p->{yyvs}->[$p->{yyvsp}-3], $p->{yyvs}->[$p->{yyvsp}-1] ); 
},
'36' => sub 
#line 163 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($BLOCK, [$p->{yyvs}->[$p->{yyvsp}-7],$p->{yyvs}->[$p->{yyvsp}-6],$p->{yyvs}->[$p->{yyvsp}-5],$p->{yyvs}->[$p->{yyvsp}-4],$p->{yyvs}->[$p->{yyvsp}-3],$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], 'LOCAL', (BuildTree($LIST, [$p->{yyvs}->[$p->{yyvsp}-5],$p->{yyvs}->[$p->{yyvsp}-4],$p->{yyvs}->[$p->{yyvsp}-3]], $p->{yyvs}->[$p->{yyvsp}-5], $p->{yyvs}->[$p->{yyvsp}-3]))[1], $p->{yyvs}->[$p->{yyvsp}-1]); 
},
'37' => sub 
#line 165 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($BLOCK, [$p->{yyvs}->[$p->{yyvsp}-5],$p->{yyvs}->[$p->{yyvsp}-4],$p->{yyvs}->[$p->{yyvsp}-3],$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], 'MENU', $p->{yyvs}->[$p->{yyvsp}-3], $p->{yyvs}->[$p->{yyvsp}-1] ); 
},
'38' => sub 
#line 167 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($BLOCK, [$p->{yyvs}->[$p->{yyvsp}-5],$p->{yyvs}->[$p->{yyvsp}-4],$p->{yyvs}->[$p->{yyvsp}-3],$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], 'NAVBAR', $p->{yyvs}->[$p->{yyvsp}-3], $p->{yyvs}->[$p->{yyvsp}-1] ); 
},
'39' => sub 
#line 169 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($BLOCK, [$p->{yyvs}->[$p->{yyvsp}-5],$p->{yyvs}->[$p->{yyvsp}-4],$p->{yyvs}->[$p->{yyvsp}-3],$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], 'WITH_LANGUAGE', $p->{yyvs}->[$p->{yyvsp}-3], $p->{yyvs}->[$p->{yyvsp}-1] ); 
},
'40' => sub 
#line 171 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($BLOCK, [$p->{yyvs}->[$p->{yyvsp}-5],$p->{yyvs}->[$p->{yyvsp}-4],$p->{yyvs}->[$p->{yyvsp}-3],$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], 'WITH_ERROR', $p->{yyvs}->[$p->{yyvsp}-3], $p->{yyvs}->[$p->{yyvsp}-1] ); 
},
'41' => sub 
#line 173 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($BLOCK, [$p->{yyvs}->[$p->{yyvsp}-5],$p->{yyvs}->[$p->{yyvsp}-4],$p->{yyvs}->[$p->{yyvsp}-3],$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], 'GUI', $p->{yyvs}->[$p->{yyvsp}-3], $p->{yyvs}->[$p->{yyvsp}-1] ); 
},
'42' => sub 
#line 175 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($JSSCRIPT, [$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-2], $p->{yyvs}->[$p->{yyvsp}-1], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'43' => sub 
#line 178 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($BLOCK, [$p->{yyvs}->[$p->{yyvsp}-5],$p->{yyvs}->[$p->{yyvsp}-4],$p->{yyvs}->[$p->{yyvsp}-3],$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-3], (BuildTree($LIST, [$p->{yyvs}->[$p->{yyvsp}-1]], $p->{yyvs}->[$p->{yyvsp}-1]))[1], undef); 
},
'44' => sub 
#line 180 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($BLOCK, [$p->{yyvs}->[$p->{yyvsp}-3],$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-3]->{'parameter'}, $p->{yyvs}->[$p->{yyvsp}-1], undef); 
},
'45' => sub 
#line 182 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($LIST, [$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'46' => sub 
#line 183 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($LIST, [$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-2], $p->{yyvs}->[$p->{yyvsp}-0] ); 
},
'53' => sub 
#line 192 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($PARENTHESE, [$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-1]); 
},
'54' => sub 
#line 193 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree(undef, [$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]],    $p->{yyvs}->[$p->{yyvsp}-1]); 
},
'55' => sub 
#line 194 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree(undef, [$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]],    $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'57' => sub 
#line 197 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($BLOCK, [$p->{yyvs}->[$p->{yyvsp}-5],$p->{yyvs}->[$p->{yyvsp}-4],$p->{yyvs}->[$p->{yyvsp}-3],$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], 'CDATA', $p->{yyvs}->[$p->{yyvsp}-3], $p->{yyvs}->[$p->{yyvsp}-1] ); 
},
'58' => sub 
#line 201 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($OR,  [$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-2], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'59' => sub 
#line 202 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($AND, [$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-2], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'60' => sub 
#line 203 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($EQ,  [$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-2], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'61' => sub 
#line 204 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($NE,  [$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-2], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'62' => sub 
#line 205 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($NEQ, [$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-2], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'63' => sub 
#line 206 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($NNE, [$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-2], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'64' => sub 
#line 207 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($NLT, [$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-2], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'65' => sub 
#line 208 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($NLE, [$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-2], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'66' => sub 
#line 209 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($NGT, [$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-2], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'67' => sub 
#line 210 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($NGE, [$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-2], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'68' => sub 
#line 211 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($IN,  [$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-2], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'69' => sub 
#line 212 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree(ord('+'), [$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-2], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'70' => sub 
#line 213 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree(ord('-'), [$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-2], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'71' => sub 
#line 214 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree(ord('*'), [$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-2], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'72' => sub 
#line 215 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree(ord('/'), [$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-2], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'73' => sub 
#line 216 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree(ord('%'), [$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-2], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'74' => sub 
#line 217 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree(ord('.'), [$p->{yyvs}->[$p->{yyvsp}-2],$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-2], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'75' => sub 
#line 220 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($NOT,     [$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'76' => sub 
#line 221 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree(ord('-'), [$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'77' => sub 
#line 222 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree(ord('+'), [$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'78' => sub 
#line 224 "tle.y"
{  my $p = shift;  $p->{yyval} = BuildTree($VARIABLE, [$p->{yyvs}->[$p->{yyvsp}-1],$p->{yyvs}->[$p->{yyvsp}-0]], $p->{yyvs}->[$p->{yyvsp}-1], $p->{yyvs}->[$p->{yyvsp}-0]); 
},
'79' => sub 
#line 226 "tle.y"
{  my $p = shift;  $p->{yyval} = undef; 
},
#line 1023 "Parser.pm"
  );
  
  if ($p->{yys} = $ENV{'YYDEBUG'})
  {
    $p->{yydebug} = int($1) if $p->{yys} =~ /^(\d)/;
  }

  $p->{yynerrs} = 0;
  $p->{yyerrflag} = 0;
  $p->{yychar} = (-1);

  $p->{yyssp} = 0;
  $p->{yyvsp} = 0;
  $p->{yyss}->[$p->{yyssp}] = $p->{yystate} = 0;

yyloop: while(1)
  {
    yyreduce: {
      last yyreduce if ($p->{yyn} = $yydefred[$p->{yystate}]);
      if ($p->{yychar} < 0)
      {
        if ((($p->{yychar}, $p->{yylval}) = 
            &{$p->{yylex}}($s)) < 0) { $p->{yychar} = 0; }
        if ($p->{yydebug})
        {
          $p->{yys} = '';
          if ($p->{yychar} <= $#yyname) 
             { $p->{yys} = $yyname[$p->{yychar}]; }
          if (!$p->{yys}) { $p->{yys} = 'illegal-symbol'; };
          warn("yydebug: state " . $p->{yystate} . 
                       ", reading " . $p->{yychar} . " (" . 
                       $p->{yys} . ")\n");
        }
      }
      if (($p->{yyn} = $yysindex[$p->{yystate}]) && 
          ($p->{yyn} += $p->{yychar}) >= 0 && 
          $p->{yyn} <= $#yycheck &&
          $yycheck[$p->{yyn}] == $p->{yychar})
      {
        warn("yydebug: state " . $p->{yystate} . 
                     ", shifting to state " .
              $yytable[$p->{yyn}] . "\n") if $p->{yydebug};
        $p->{yyss}->[++$p->{yyssp}] = $p->{yystate} = 
          $yytable[$p->{yyn}];
        $p->{yyvs}->[++$p->{yyvsp}] = $p->{yylval};
        $p->{yychar} = (-1);
        --$p->{yyerrflag} if $p->{yyerrflag} > 0;
        next yyloop;
      }
      if (($p->{yyn} = $yyrindex[$p->{yystate}]) && 
          ($p->{yyn} += $p->{'yychar'}) >= 0 &&
          $p->{yyn} <= $#yycheck &&
          $yycheck[$p->{yyn}] == $p->{yychar})
      {
        $p->{yyn} = $yytable[$p->{yyn}];
        last yyreduce;
      }
      if (! $p->{yyerrflag}) {
        &{$p->{yyerror}}('syntax error', $s);
        ++$p->{yynerrs};
      }
      return(undef) if $p->yy_err_recover;
    } # yyreduce
    warn("yydebug: state " . $p->{yystate} . 
                 ", reducing by rule " . 
                 $p->{yyn} . " (" . $yyrule[$p->{yyn}] . 
                 ")\n") if $p->{yydebug};
    $p->{yym} = $yylen[$p->{yyn}];
    $p->{yyval} = $p->{yyvs}->[$p->{yyvsp}+1-$p->{yym}];
    $ActiontoExec{$p->{yyn}}->($p) if(defined($ActiontoExec{$p->{yyn}})); 
    $p->{yyssp} -= $p->{yym};
    $p->{yystate} = $p->{yyss}->[$p->{yyssp}];
    $p->{yyvsp} -= $p->{yym};
    $p->{yym} = $yylhs[$p->{yyn}];
    if ($p->{yystate} == 0 && $p->{yym} == 0)
    {
      warn("yydebug: after reduction, shifting from state 0 ",
            "to state $YYFINAL\n") if $p->{yydebug};
      $p->{yystate} = $YYFINAL;
      $p->{yyss}->[++$p->{yyssp}] = $YYFINAL;
      $p->{yyvs}->[++$p->{yyvsp}] = $p->{yyval};
      if ($p->{yychar} < 0)
      {
        if ((($p->{yychar}, $p->{yylval}) = 
            &{$p->{yylex}}($s)) < 0) { $p->{yychar} = 0; }
        if ($p->{yydebug})
        {
          $p->{yys} = '';
          if ($p->{yychar} <= $#yyname) 
            { $p->{yys} = $yyname[$p->{yychar}]; }
          if (!$p->{yys}) { $p->{yys} = 'illegal-symbol'; }
          warn("yydebug: state $YYFINAL, reading " . 
               $p->{yychar} . " (" . $p->{yys} . ")\n");
        }
      }
      return ($p->{yyvs}->[1]) if $p->{yychar} == 0;
      next yyloop;
    }
    if (($p->{yyn} = $yygindex[$p->{yym}]) && 
        ($p->{yyn} += $p->{yystate}) >= 0 && 
        $p->{yyn} <= $#yycheck && 
        $yycheck[$p->{yyn}] == $p->{yystate})
    {
        $p->{yystate} = $yytable[$p->{yyn}];
    } else {
        $p->{yystate} = $yydgoto[$p->{yym}];
    }
    warn("yydebug: after reduction, shifting from state " . 
        $p->{yyss}->[$p->{yyssp}] . " to state " . 
        $p->{yystate} . "\n") if $p->{yydebug};
    $p->{yyss}[++$p->{yyssp}] = $p->{yystate};
    $p->{yyvs}[++$p->{yyvsp}] = $p->{yyval};
  } # yyloop
} # yyparse
#line 230 "tle.y"

#line 1140 "Parser.pm"
1;
